import 'package:clean_android_design/src/settings/clean_android_design_style.dart';
import 'package:clean_android_design/src/utils/item_section_widget.dart';
import 'package:flutter/material.dart';

class DefaultFieldWidget extends StatelessWidget implements IListItem {
  final Text title;
  final Widget child;
  final bool isFirst;
  final bool isLast;
  final bool separationLine;
  final EdgeInsets childPadding;

  const DefaultFieldWidget(
      {Key key,
      this.title,
      this.child,
      this.isFirst = false,
      this.isLast = false,
      this.separationLine = true,
      this.childPadding})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    var borderRadius = BorderRadius.only(
        bottomLeft: isLast ? Radius.circular(30) : Radius.zero,
        bottomRight: isLast ? Radius.circular(30) : Radius.zero,
        topLeft: isFirst ? Radius.circular(30) : Radius.zero,
        topRight: isFirst ? Radius.circular(30) : Radius.zero);

    return Container(
      width: MediaQuery.of(context).size.width,
      decoration: BoxDecoration(
        borderRadius: borderRadius,
        //color: Colors.white,
      ),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          title != null
              ? Padding(
                  padding: const EdgeInsets.only(
                      left: 30, right: 30, bottom: 3, top: 13),
                  child: DefaultTextStyle(
                      style: TextStyles.textStyleSize(14), child: title),
                )
              : Container(),
          Padding(
            padding: childPadding ??
                const EdgeInsets.only(left: 30, right: 30, bottom: 13, top: 6),
            child: child,
          ),
          !isLast && separationLine
              ? Padding(
                  padding: const EdgeInsets.symmetric(horizontal: 30),
                  child: Divider(
                    color: CleanAndroidDesignDefaultColors.defaultColorLight,
                    height: 1.1,
                    thickness: 1.1,
                  ),
                )
              : Container()
        ],
      ),
    );
  }

  IListItem copyWithPosition({bool isFirst, bool isLast}) {
    return DefaultFieldWidget(
      child: this.child,
      key: this.key,
      title: this.title,
      isFirst: isFirst ?? this.isFirst,
      isLast: isLast ?? this.isLast,
      separationLine: this.separationLine,
      childPadding: this.childPadding,
    );
  }
}
